import type { EventType } from './eventType';
/**
 * Insights event.
 */
export declare type InsightEvent = {
    eventType: EventType;
    /**
     * A user-defined string used to categorize events.
     */
    eventName: string;
    /**
     * Name of the targeted index.
     */
    index: string;
    /**
     * A user identifier. Depending if the user is logged-in or not, several strategies can be used from a sessionId to a technical identifier. You should always send pseudonymous or anonymous userTokens.
     */
    userToken: string;
    /**
     * Time of the event expressed in milliseconds since the Unix epoch.
     */
    timestamp?: number;
    /**
     * Algolia queryID. This is required when an event is tied to a search.
     */
    queryID?: string;
    /**
     * An array of index objectID. Limited to 20 objects. An event can’t have both objectIDs and filters at the same time.
     */
    objectIDs?: string[];
    /**
     * An array of filters. Limited to 10 filters. An event can’t have both objectIDs and filters at the same time.
     */
    filters?: string[];
    /**
     * Position of the click in the list of Algolia search results. This field is required if a queryID is provided. One position must be provided for each objectID.
     */
    positions?: number[];
};
//# sourceMappingURL=insightEvent.d.ts.map